@@ -7,4 +7,6 @@ from .coco_cider_d import CocoCIDErD
 from .coco_meteor import CocoMETEOR
 from .coco_rouge_l import CocoRougeL
 from .coco_spice import CocoSPICE
+from .evaluate import CustomEvaluate, AACEvaluate
+from .spider_max import spider_max
 from .spider import SPIDEr
