@@ -6,4 +6,7 @@ from .coco_cider_d import coco_cider_d
 from .coco_meteor import coco_meteor
 from .coco_rouge_l import coco_rouge_l
 from .coco_spice import coco_spice
+from .evaluate import custom_evaluate, aac_evaluate
+from .mult_cands import mult_cands_metric
+from .spider_max import spider_max
 from .spider import spider
